==> gss_1.0-4.tar.gz: gss/data/nox.R <==
"nox" <-
structure(list(nox = c(52.356, 12.088, 3.362, 23.913, 0.439, 
30.371, 0.26, 1.602, 13.111, 0.223, 49.39, 1, 0.944, 1.694, 0.794, 
4.02, 5.891, 7.553, 65.353, 31.196, 6.189, 23.028, 1.04, 0.071, 
0.535, 0.052, 47.556, 6.529, 22.81, 45.385, 0.649, 2.566, 0.159, 
20.548, 1.728, 5.08, 40.107, 4.363, 1.064, 10.036, 37.967, 2.686, 
7.381, 0.89, 0.186, 10.926, 2.857, 43.577, 5.196, 32.953, 15.088, 
5.611, 16.994, 61.724, 60.745, 3.997, 2.726, 44.212, 10.677, 
0.432, 4.252, 48.867, 26.04, 53.157, 0.303, 49.714, 43.503, 35.611, 
1.478, 0.384, 17.193, 0.786, 3.561, 38.889, 9.064, 0.901, 42.436, 
0.429, 0.506, 8.793, 51.979, 0.201, 0.177, 0.178, 0.312, 0.051, 
0.149, 6.859), equi = c(0.907, 0.761, 1.108, 1.016, 1.189, 1.001, 
1.231, 1.123, 1.042, 1.215, 0.93, 1.152, 1.138, 0.601, 0.696, 
0.686, 1.072, 1.074, 0.934, 0.808, 1.071, 1.009, 1.142, 1.229, 
1.175, 0.568, 0.977, 0.767, 1.006, 0.893, 1.152, 0.693, 1.232, 
1.036, 1.125, 1.081, 0.868, 0.762, 1.144, 1.045, 0.797, 1.115, 
1.07, 1.219, 0.637, 0.733, 0.715, 0.872, 0.765, 0.878, 0.811, 
0.676, 1.045, 0.968, 0.846, 0.684, 0.729, 0.911, 0.808, 1.168, 
0.749, 0.892, 1.002, 0.812, 1.23, 0.804, 0.813, 1.002, 0.696, 
1.199, 1.03, 0.602, 0.694, 0.816, 1.037, 1.181, 0.899, 1.227, 
1.18, 0.795, 0.99, 1.201, 0.629, 0.608, 0.584, 0.562, 0.535, 
0.655), comp = c(12, 12, 12, 12, 12, 9, 9, 9, 12, 12, 12, 12, 
15, 18, 7.5, 12, 12, 15, 15, 9, 9, 7.5, 7.5, 18, 18, 15, 15, 
7.5, 7.5, 9, 15, 15, 15, 15, 15, 9, 9, 7.5, 7.5, 7.5, 18, 18, 
18, 18, 9, 9, 9, 9, 7.5, 7.5, 7.5, 15, 18, 18, 15, 15, 7.5, 7.5, 
7.5, 7.5, 7.5, 7.5, 7.5, 18, 18, 18, 12, 12, 9, 9, 9, 15, 15, 
15, 15, 15, 7.5, 7.5, 9, 7.5, 18, 18, 7.5, 9, 12, 15, 18, 18)), .Names = c("nox", 
"equi", "comp"), row.names = c("1", "2", "3", "4", "5", "6", 
"7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", 
"18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", 
"29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", 
"40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50", 
"51", "52", "53", "54", "55", "56", "57", "58", "59", "60", "61", 
"62", "63", "64", "65", "66", "67", "68", "69", "70", "71", "72", 
"73", "74", "75", "76", "77", "78", "79", "80", "81", "82", "83", 
"84", "85", "86", "87", "88"), class = "data.frame")

==> gss_2.0-1.tar.gz: gss/data/nox.R <==
nox <-
structure(list(nox = c(52.356, 12.088, 3.362, 23.913, 0.439, 
30.371, 0.26, 1.602, 13.111, 0.223, 49.39, 1, 0.944, 1.694, 0.794, 
4.02, 5.891, 7.553, 65.353, 31.196, 6.189, 23.028, 1.04, 0.071, 
0.535, 0.052, 47.556, 6.529, 22.81, 45.385, 0.649, 2.566, 0.159, 
20.548, 1.728, 5.08, 40.107, 4.363, 1.064, 10.036, 37.967, 2.686, 
7.381, 0.89, 0.186, 10.926, 2.857, 43.577, 5.196, 32.953, 15.088, 
5.611, 16.994, 61.724, 60.745, 3.997, 2.726, 44.212, 10.677, 
0.432, 4.252, 48.867, 26.04, 53.157, 0.303, 49.714, 43.503, 35.611, 
1.478, 0.384, 17.193, 0.786, 3.561, 38.889, 9.064, 0.901, 42.436, 
0.429, 0.506, 8.793, 51.979, 0.201, 0.177, 0.178, 0.312, 0.051, 
0.149, 6.859), equi = c(0.907, 0.761, 1.108, 1.016, 1.189, 1.001, 
1.231, 1.123, 1.042, 1.215, 0.93, 1.152, 1.138, 0.601, 0.696, 
0.686, 1.072, 1.074, 0.934, 0.808, 1.071, 1.009, 1.142, 1.229, 
1.175, 0.568, 0.977, 0.767, 1.006, 0.893, 1.152, 0.693, 1.232, 
1.036, 1.125, 1.081, 0.868, 0.762, 1.144, 1.045, 0.797, 1.115, 
1.07, 1.219, 0.637, 0.733, 0.715, 0.872, 0.765, 0.878, 0.811, 
0.676, 1.045, 0.968, 0.846, 0.684, 0.729, 0.911, 0.808, 1.168, 
0.749, 0.892, 1.002, 0.812, 1.23, 0.804, 0.813, 1.002, 0.696, 
1.199, 1.03, 0.602, 0.694, 0.816, 1.037, 1.181, 0.899, 1.227, 
1.18, 0.795, 0.99, 1.201, 0.629, 0.608, 0.584, 0.562, 0.535, 
0.655), comp = c(12, 12, 12, 12, 12, 9, 9, 9, 12, 12, 12, 12, 
15, 18, 7.5, 12, 12, 15, 15, 9, 9, 7.5, 7.5, 18, 18, 15, 15, 
7.5, 7.5, 9, 15, 15, 15, 15, 15, 9, 9, 7.5, 7.5, 7.5, 18, 18, 
18, 18, 9, 9, 9, 9, 7.5, 7.5, 7.5, 15, 18, 18, 15, 15, 7.5, 7.5, 
7.5, 7.5, 7.5, 7.5, 7.5, 18, 18, 18, 12, 12, 9, 9, 9, 15, 15, 
15, 15, 15, 7.5, 7.5, 9, 7.5, 18, 18, 7.5, 9, 12, 15, 18, 18)), .Names = c("nox", 
"equi", "comp"), row.names = c(NA, 88L), class = "data.frame")
